@@ -1,17 +1,21 @@
 # -*- coding: utf-8 -*-
-"""Useful utility functions."""
+from __future__ import unicode_literals, absolute_import
+
+"""
+Useful utility functions.
+"""
 
 import os
 
 from django.http import HttpResponse
 from django.conf import settings
 
-from twilio.twiml import Response
+from twilio import twiml
 
-from django_twilio.models import Caller, Credential
+from .models import Caller, Credential
 
 
-def discover_twilio_creds(user=None):
+def discover_twilio_credentials(user=None):
     """ Due to the multiple ways of providing SID / AUTH tokens through
         this package, this function will search in the various places that
         credentials might be stored.
@@ -23,24 +27,32 @@ def discover_twilio_creds(user=None):
         2. Environment variables
         3. django.conf settings
 
-        We recommend using enviornment variables were possible, it is the
+        We recommend using environment variables were possible; it is the
         most secure option
-
     """
 
     SID = 'TWILIO_ACCOUNT_SID'
     AUTH = 'TWILIO_AUTH_TOKEN'
 
     if user:
-        creds = Credential.objects.filter(user=user.id)
-        if creds.exists():
-            creds = creds[0]
-            return (creds.account_sid, creds.auth_token)
+        credentials = Credential.objects.filter(user=user.id)
+        if credentials.exists():
+            credentials = credentials[0]
+            return credentials.account_sid, credentials.auth_token
 
-    if SID and AUTH in os.environ:
-        return (os.environ[SID], os.environ[AUTH])
+    if SID in os.environ and AUTH in os.environ:
+        return os.environ[SID], os.environ[AUTH]
 
-    return (settings.TWILIO_ACCOUNT_SID, settings.TWILIO_AUTH_TOKEN)
+    if hasattr(settings, SID) and hasattr(settings, AUTH):
+        return settings.TWILIO_ACCOUNT_SID, settings.TWILIO_AUTH_TOKEN
+
+    raise AttributeError(
+        "Could not find {sid} or {auth} in environment variables, "
+        "User credentials, or django project settings.".format(
+            sid=SID,
+            auth=AUTH,
+        )
+    )
 
 
 def get_blacklisted_response(request):
@@ -56,10 +68,14 @@ def get_blacklisted_response(request):
     try:
         caller = Caller.objects.get(phone_number=request.REQUEST['From'])
         if caller.blacklisted:
-            r = Response()
+            r = twiml.Response()
             r.reject()
             return HttpResponse(str(r), content_type='application/xml')
-    except Exception, e:
+    except Exception:
         pass
 
     return None
+
+
+# Backwards compatibility for a poorly named function
+discover_twilio_creds = discover_twilio_credentials
